==> haskell-text-short-0.1.2-57-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-short.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-short
version: 0.1.2
id: text-short-0.1.2-9zgIFqAcp7Z9LXQNr4FGEe
key: text-short-0.1.2-9zgIFqAcp7Z9LXQNr4FGEe
license: BSD-3-Clause
maintainer: hvr@gnu.org
author: Herbert Valerio Riedel
synopsis: Memory-efficient representation of Unicode text strings
description:
    This package provides the '\''ShortText'\'' type which is suitable for keeping many short strings in memory. This is similiar to how '\''ShortByteString'\'' relates to '\''ByteString'\''.
    .
    The main difference between '\''Text'\'' and '\''ShortText'\'' is that '\''ShortText'\'' uses UTF-8 instead of UTF-16 internally and also doesn'\''t support zero-copy slicing (thereby saving 2 words). Consequently, the memory footprint of a (boxed) '\''ShortText'\'' value is 4 words (2 words when unboxed) plus the length of the UTF-8 encoded payload.
category: Data
abi: 2e867d50b9cb31704744a701c556d4ea
exposed: True
exposed-modules:
    Data.Text.Short Data.Text.Short.Partial Data.Text.Short.Unsafe
hidden-modules: Data.Text.Short.Internal PrimOps
import-dirs: /usr/lib/ghc-8.6.5/site-local/text-short-0.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/text-short-0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/text-short-0.1.2
hs-libraries: HStext-short-0.1.2-9zgIFqAcp7Z9LXQNr4FGEe
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2 deepseq-1.4.4.0
    ghc-prim-0.5.3 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-text-short/html/text-short.haddock
haddock-html: /usr/share/doc/haskell-text-short/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-short-0.1.2-59-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-short.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-short
version: 0.1.2
id: text-short-0.1.2-D8y09cXKjcOItHFmc6vTnC
key: text-short-0.1.2-D8y09cXKjcOItHFmc6vTnC
license: BSD-3-Clause
maintainer: hvr@gnu.org
author: Herbert Valerio Riedel
synopsis: Memory-efficient representation of Unicode text strings
description:
    This package provides the '\''ShortText'\'' type which is suitable for keeping many short strings in memory. This is similiar to how '\''ShortByteString'\'' relates to '\''ByteString'\''.
    .
    The main difference between '\''Text'\'' and '\''ShortText'\'' is that '\''ShortText'\'' uses UTF-8 instead of UTF-16 internally and also doesn'\''t support zero-copy slicing (thereby saving 2 words). Consequently, the memory footprint of a (boxed) '\''ShortText'\'' value is 4 words (2 words when unboxed) plus the length of the UTF-8 encoded payload.
category: Data
abi: 29d2407699c5ab7c1655a7457eaba57b
exposed: True
exposed-modules:
    Data.Text.Short Data.Text.Short.Partial Data.Text.Short.Unsafe
hidden-modules: Data.Text.Short.Internal PrimOps
import-dirs: /usr/lib/ghc-8.6.5/site-local/text-short-0.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/text-short-0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/text-short-0.1.2
hs-libraries: HStext-short-0.1.2-D8y09cXKjcOItHFmc6vTnC
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2 deepseq-1.4.4.0
    ghc-prim-0.5.3 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-text-short/html/text-short.haddock
haddock-html: /usr/share/doc/haskell-text-short/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
